#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class AMPTag(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AMPTag
                | 
                | This interface provides the methods to handle the feature
                | AMPTag.
                | 
                | DESCRIPTION :
                | AMP generates finally a RobotTask with Operations/RobotMotions( having
                | attributes ) and a set of tags( seam ). RobotTask with Operations/RobotMotions(
                | having attributes ) and the set of tags have information. For example each tag
                | has the information regarding XYZYPR values. RobotMotions have information
                | regarding weld speed etc. The current implementation of AMP is such that these
                | information are first populated in AMPTags. The list of AMPTags is put in an
                | AMPPath. When AMP is nearing its’ end of execution, tags and RobotTask with
                | appropriate Operations/RobotMotions are created and populated with these
                | information by retrieving it from the AMPTags( For each Operation/RobotMotion
                | and tag there is a corresponding AMPTag from which these information are
                | retrieved ). AMPTags are non-persistent and they are just intermediate buffers
                | for holding these information. Through the ability of executing VB script file
                | by embedding the call to it through the "Execute" keyword, these AMPTags are
                | made available to the user for further customization of these information.
                | "Execute" keyword facilitates calling the VB script file’s CATMain method by
                | passing it the AMPPath object as the single argument.
                | 
                | USAGE :
                | This interface can be used only during AMP primitive file execution and not in
                | a stand alone VB script file. This interface can only be used in conjunction
                | with AMPPath interface. Please see the usage instructions in the AMPPath
                | interface.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.amp_tag = com_object

    def add_attribute_real(self, name: str, value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddAttributeReal(CATBSTR Name,
                | double Value)
                | 
                |     Function to add real attribute on the given AMPTag.
                | 
                |     Parameters:
                | 
                |         Name
                |             Name of the attribute to be added. 
                |         Value
                |             Value of the added attribute. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param str name:
        :param float value:
        :rtype: None
        """
        return self.amp_tag.AddAttributeReal(name, value)

    def add_attribute_string(self, name: str, value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddAttributeString(CATBSTR Name,
                | CATBSTR Value)
                | 
                |     Function to add string attribute on the given AMPTag.
                | 
                |     Parameters:
                | 
                |         Name
                |             Name of the attribute to be added. 
                |         Value
                |             Value of the added attribute. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param str name:
        :param str value:
        :rtype: None
        """
        return self.amp_tag.AddAttributeString(name, value)

    def add_aux_attribute(self, i_name: str, i_value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddAuxAttribute(CATBSTR iName,
                | CATBSTR iValue)
                | 
                |     Function to add an auxilliary attribute to the given
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the auxilliary attribute. 
                |         iValue
                |             The value of the auxilliary attribute. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str i_name:
        :param str i_value:
        :rtype: None
        """
        return self.amp_tag.AddAuxAttribute(i_name, i_value)

    def get_attribute_value_real(self, name: str, o_value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAttributeValueReal(CATBSTR Name,
                | double oValue)
                | 
                |     Function to get the value of the given real attribute on the given
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         Name
                |             Name of the attribute whose value has to be obtained.
                |             
                |         Value
                |             Value of the attribute. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :param float o_value:
        :rtype: None
        """
        return self.amp_tag.GetAttributeValueReal(name, o_value)

    def get_attribute_value_string(self, name: str, value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAttributeValueString(CATBSTR Name,
                | CATBSTR Value)
                | 
                |     Function to get the value of the given string attribute on the given
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         Name
                |             Name of the attribute whose value has to be obtained.
                |             
                |         Value
                |             Value of the attribute. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param str name:
        :param str value:
        :rtype: None
        """
        return self.amp_tag.GetAttributeValueString(name, value)

    def get_aux_attribute(self, i_index: int, o_name: str, o_value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAuxAttribute(short iIndex,
                | CATBSTR oName,
                | CATBSTR oValue)
                | 
                |     Function to get an auxilliary attribute value of the given
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the auxilliary attribute. 
                |         oName
                |             The name of the auxilliary attribute. 
                |         oValue
                |             The value of the auxilliary attribute. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_index:
        :param str o_name:
        :param str o_value:
        :rtype: None
        """
        return self.amp_tag.GetAuxAttribute(i_index, o_name, o_value)

    def get_aux_attribute_num(self, o_num: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAuxAttributeNum(short oNum)
                | 
                |     Function to get the number of auxilliary attributes of the given
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         oNum
                |             The number of auxilliary attributes of the given AMPTag.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int o_num:
        :rtype: None
        """
        return self.amp_tag.GetAuxAttributeNum(o_num)

    def get_aux_axes_values(self, o_auxillary_axis_values: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAuxAxesValues(CATSafeArrayVariant
                | oAuxillaryAxisValues)
                | 
                |     Function to get the auxilliary axes values of the given
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         oAuxillaryAxisValues
                |             The auxilliary axes values of the given AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param tuple o_auxillary_axis_values:
        :rtype: None
        """
        return self.amp_tag.GetAuxAxesValues(o_auxillary_axis_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_aux_axes_values'
        # # vba_code = """
        # # Public Function get_aux_axes_values(amp_tag)
        # #     Dim oAuxillaryAxisValues (2)
        # #     amp_tag.GetAuxAxesValues oAuxillaryAxisValues
        # #     get_aux_axes_values = oAuxillaryAxisValues
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_config(self, oconfig: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetConfig(short oconfig)
                | 
                |     Function to get the config value of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         oconfig
                |             The config value of the given AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int oconfig:
        :rtype: None
        """
        return self.amp_tag.GetConfig(oconfig)

    def get_op_type(self, o_op_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOpType(short oOpType)
                | 
                |     Function to get the operation type of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         oOpType
                |             The operation type of the given AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int o_op_type:
        :rtype: None
        """
        return self.amp_tag.GetOpType(o_op_type)

    def get_position(self, o_transform: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPosition(CATSafeArrayVariant oTransform)
                | 
                |     Function to get the position( array of doubles; X, Y, Z, Yaw, Roll, Pitch
                |     values ) of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         oTransform
                |             Array containing X, Y, Z, Yaw, Roll, Pitch values in sequence.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param tuple o_transform:
        :rtype: None
        """
        return self.amp_tag.GetPosition(o_transform)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_position'
        # # vba_code = """
        # # Public Function get_position(amp_tag)
        # #     Dim oTransform (2)
        # #     amp_tag.GetPosition oTransform
        # #     get_position = oTransform
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_type(self, o_tag_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetType(CATBSTR oTagType)
                | 
                |     Function to get the type of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         oTagType
                |             The type of the given AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param str o_tag_type:
        :rtype: None
        """
        return self.amp_tag.GetType(o_tag_type)

    def get_via(self, o_via_status: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetVia(short oViaStatus)
                | 
                |     Function to get the via status of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         oViaStatus
                |             The via status of the given AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int o_via_status:
        :rtype: None
        """
        return self.amp_tag.GetVia(o_via_status)

    def get_weld_speed(self, o_speed: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetWeldSpeed(double oSpeed)
                | 
                |     Function to get the weld speed of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         oSpeed
                |             The weld speed of the given AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param float o_speed:
        :rtype: None
        """
        return self.amp_tag.GetWeldSpeed(o_speed)

    def remove_attribute(self, name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAttribute(CATBSTR Name)
                | 
                |     Function to remove an existing attribute on the given
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         Name
                |             Name of the attribute to be removed. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param str name:
        :rtype: None
        """
        return self.amp_tag.RemoveAttribute(name)

    def remove_aux_attribute(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAuxAttribute(short iIndex)
                | 
                |     Function to remove an auxilliary attribute of the given
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the auxilliary attribute. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_index:
        :rtype: None
        """
        return self.amp_tag.RemoveAuxAttribute(i_index)

    def set_attribute_value_real(self, name: str, value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttributeValueReal(CATBSTR Name,
                | double Value)
                | 
                |     Function to set the value of the given real attribute on the given
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         Name
                |             Name of the attribute whose value has to be set. 
                |         Value
                |             The Value to be set. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param str name:
        :param float value:
        :rtype: None
        """
        return self.amp_tag.SetAttributeValueReal(name, value)

    def set_attribute_value_string(self, name: str, value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttributeValueString(CATBSTR Name,
                | CATBSTR Value)
                | 
                |     Function to set the value of the given string attribute on the given
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         Name
                |             Name of the attribute whose value has to be set. 
                |         Value
                |             The Value to be set. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param str name:
        :param str value:
        :rtype: None
        """
        return self.amp_tag.SetAttributeValueString(name, value)

    def set_aux_axes_values(self, i_auxillary_axis_values: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAuxAxesValues(CATSafeArrayVariant
                | iAuxillaryAxisValues)
                | 
                |     Function to set the auxilliary axes values of the given
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         iAuxillaryAxisValues
                |             The auxilliary axes values of the given AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param tuple i_auxillary_axis_values:
        :rtype: None
        """
        return self.amp_tag.SetAuxAxesValues(i_auxillary_axis_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_aux_axes_values'
        # # vba_code = """
        # # Public Function set_aux_axes_values(amp_tag)
        # #     Dim iAuxillaryAxisValues (2)
        # #     amp_tag.SetAuxAxesValues iAuxillaryAxisValues
        # #     set_aux_axes_values = iAuxillaryAxisValues
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_config(self, iconfig: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetConfig(short iconfig)
                | 
                |     Function to set the config value of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         iconfig
                |             The config value of the given AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int iconfig:
        :rtype: None
        """
        return self.amp_tag.SetConfig(iconfig)

    def set_op_type(self, i_op_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOpType(short iOpType)
                | 
                |     Function to set the operation type of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         iOpType
                |             The operation type to be set for the given AMPTag.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_op_type:
        :rtype: None
        """
        return self.amp_tag.SetOpType(i_op_type)

    def set_position(self, i_transform: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPosition(CATSafeArrayVariant iTransform)
                | 
                |     Function to set the position( array of doubles; X, Y, Z, Yaw, Roll, Pitch
                |     values ) of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         iTransform
                |             Array containing X, Y, Z, Yaw, Roll, Pitch values in sequence.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param tuple i_transform:
        :rtype: None
        """
        return self.amp_tag.SetPosition(i_transform)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_position'
        # # vba_code = """
        # # Public Function set_position(amp_tag)
        # #     Dim iTransform (2)
        # #     amp_tag.SetPosition iTransform
        # #     set_position = iTransform
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_type(self, i_tag_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetType(CATBSTR iTagType)
                | 
                |     Function to set the type of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         iTagType
                |             The type to be set for the given AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param str i_tag_type:
        :rtype: None
        """
        return self.amp_tag.SetType(i_tag_type)

    def set_via(self, i_via_status: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVia(short iViaStatus)
                | 
                |     Function to set the via status of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         iViaStatus
                |             The via status of the given AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_via_status:
        :rtype: None
        """
        return self.amp_tag.SetVia(i_via_status)

    def set_weld_speed(self, i_speed: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetWeldSpeed(double iSpeed)
                | 
                |     Function to set the weld speed of the given AMPTag.
                | 
                |     Parameters:
                | 
                |         iSpeed
                |             The weld speed to be set for the given AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param float i_speed:
        :rtype: None
        """
        return self.amp_tag.SetWeldSpeed(i_speed)

    def __repr__(self):
        return f'AMPTag(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_work_interfaces.wi_text import WIText


class WIDataCollection(WIText):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBWorkInterfaces.WIText
                |                         WIDataCollection

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.wi_data_collection = com_object

    def get_parameters_list(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetParametersList() As CATSafeArrayVariant
                | 
                |     Gets a List of Parameters defined on this activity
                |     Role: Gets a List of Parameters defined on this activity
                | 
                |     Parameters:
                | 
                |         iPath
                |             a CATSafeArrayVariant of CATBSTR that has the list of Parameters.
                |
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: tuple
        """
        return self.wi_data_collection.GetParametersList()

    def set_parameters_list(self, i_list_of_parameters: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetParametersList(CATSafeArrayVariant
                | iListOfParameters)
                | 
                |     Sets a List of Parameters defined on this activity
                |     Role: Sets a List of Parameters defined on this activity
                | 
                |     Parameters:
                | 
                |         iPath
                |             a CATSafeArrayVariant of CATBSTR that has the list of Parameters.
                |
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param tuple i_list_of_parameters:
        :rtype: None
        """
        return self.wi_data_collection.SetParametersList(i_list_of_parameters)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_parameters_list'
        # # vba_code = """
        # # Public Function set_parameters_list(wi_data_collection)
        # #     Dim iListOfParameters (2)
        # #     wi_data_collection.SetParametersList iListOfParameters
        # #     set_parameters_list = iListOfParameters
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'WIDataCollection(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.funct_system_interfaces.functional_object import FunctionalObject
from pycatia.funct_system_interfaces.functional_object_proxy import FunctionalObjectProxy
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant

if TYPE_CHECKING:
    from pycatia.funct_system_interfaces.functional_description import FunctionalDescription


class FunctionalObjects(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     FunctionalObjects
                | 
                | Interface to access a collection of FunctionalObjects.
    
    """

    def __init__(self, com_object, child_object=FunctionalObject):
        super().__init__(com_object, child_object=FunctionalObject)
        self.functional_objects = com_object
        self.child_object = FunctionalObject

    def create(self, i_name: str) -> FunctionalObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Create(CATBSTR iName) As FunctionalObject
                | 
                |     Creates a FunctionalObject.

        :param str i_name:
        :rtype: FunctionalObject
        """
        return FunctionalObject(self.functional_objects.Create(i_name))

    def create_proxy(self, i_name: str, i_desc: 'FunctionalDescription') -> FunctionalObjectProxy:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateProxy(CATBSTR iName,
                | FunctionalDescription iDesc) As FunctionalObjectProxy
                | 
                |     Creates a FunctionalObjectProxi.

        :param str i_name:
        :param FunctionalDescription i_desc:
        :rtype: FunctionalObjectProxy
        """
        return FunctionalObjectProxy(self.functional_objects.CreateProxy(i_name, i_desc.com_object))

    def delete(self, i_object: FunctionalObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Delete(FunctionalObject iObject)
                | 
                |     Deletes a FunctionalObject.

        :param FunctionalObject i_object:
        :rtype: None
        """
        return self.functional_objects.Delete(i_object.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete'
        # # vba_code = """
        # # Public Function delete(functional_objects)
        # #     Dim iObject (2)
        # #     functional_objects.Delete iObject
        # #     delete = iObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def elem(self, i_index: cat_variant) -> FunctionalObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Elem(CATVariant iIndex) As FunctionalObject
                | 
                |     Returns an action using its index or its name from the actions
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the action to retrieve from the collection
                |             of actions. As a numerics, this index is the rank of the action in the
                |             collection. The index of the first action in the collection is 1, and the index
                |             of the last action is Count. As a string, it is the name you assigned to the
                |             action using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved action 
                |     Example:
                |         This example retrieves in Obj1 the fifth object in the collection and
                |         in Obj2 the action named Valve.
                | 
                |          Dim Obj1 As FunctionalObject
                |          Set Obj1 = Desc.Object(5)
                |          Dim Obj2 As FunctionalObject
                |          Set Obj2 = Desc.Object("Valve")

        :param cat_variant i_index:
        :rtype: FunctionalObject
        """
        return FunctionalObject(self.functional_objects.Elem(i_index))

    def __repr__(self):
        return f'FunctionalObjects(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.mec_mod_interfaces.hybrid_shapes import HybridShapes
from pycatia.mec_mod_interfaces.sketches import Sketches
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.mec_mod_interfaces.bodies import Bodies
    from pycatia.mec_mod_interfaces.ordered_geometrical_sets import OrderedGeometricalSets
    from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class OrderedGeometricalSet(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     OrderedGeometricalSet
                | 
                | The object is an ordered geometrical set.
                | The ordered geometrical set manages a set of hybrid shapes, a set of bodies and
                | a set of ordered geometrical sets.
                | It belongs to the OrderedGeometricalSets collection of a Part or
                | OrderedGeometricalSet object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.ordered_geometrical_set = com_object

    @property
    def bodies(self) -> 'Bodies':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Bodies() As Bodies (Read Only)
                | 
                |     Returns the ordered geometrical set's Bodies collection.
                | 
                |     Example:
                |         The following example returns in bodyColl the collection of bodies of
                |         the ordered geometrical set OrderedGeometricalSet1 :
                | 
                |          Set bodyColl = OrderedGeometricalSet1.Bodies

        :rtype: Bodies
        """
        from pycatia.mec_mod_interfaces.bodies import Bodies
        return Bodies(self.ordered_geometrical_set.Bodies)

    @property
    def hybrid_shapes(self) -> HybridShapes:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property HybridShapes() As HybridShapes (Read Only)
                | 
                |     Returns the list of hybrid shapes included in the ordered geometrical
                |     set.
                | 
                |     Returns:
                |         oHybridShapes The list of hybrid shapes in the ordered geometrical set
                |         (@see CATIAHybridShapes
                |         for more information).
                | 
                |         Example:
                |             The following example returns in HybridShapes1 the list
                |             of
                |             hybrid shapes in the ordered geometrical
                |             setOrderedGeometricalSet1:
                | 
                |              Dim HybridShapes1 As HybridShapes
                |              Set HybridShapes1 = OrderedGeometricalSet1.HybridShapes

        :rtype: HybridShapes
        """

        return HybridShapes(self.ordered_geometrical_set.HybridShapes)

    @property
    def ordered_geometrical_sets(self) -> 'OrderedGeometricalSets':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property OrderedGeometricalSets() As OrderedGeometricalSets (Read
                | Only)
                | 
                |     Returns the ordered geometrical set's OrderedGeometricalSets
                |     collection.
                | 
                |     Example:
                |         The following example returns in OrderedGeometricalSetColl the
                |         collection of ordered geometrical set of the ordered geometrical set
                |         OrderedGeometricalSet1 :
                | 
                |          Set OrderedGeometricalSetColl = OrderedGeometricalSet1.OrderedGeometricalSets

        :rtype: OrderedGeometricalSets
        """
        from pycatia.mec_mod_interfaces.ordered_geometrical_sets import OrderedGeometricalSets
        return OrderedGeometricalSets(self.ordered_geometrical_set.OrderedGeometricalSets)

    @property
    def ordered_sketches(self) -> Sketches:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property OrderedSketches() As Sketches (Read Only)
                | 
                |     Returns the ordered geometrical set's Sketches collection. These sketches
                |     are those inside the ordered geometrical set at all
                |     levels.
                | 
                |     Example:
                |         The following example returns in sketchesCollection the collection of
                |         sketches of an ordered geometrical set :
                | 
                |          Set sketchesCollection = OrderedGeometricalSet1.OrderedSketches

        :rtype: Sketches
        """

        return Sketches(self.ordered_geometrical_set.OrderedSketches)

    def insert_hybrid_shape(self, i_hybrid_shape: 'HybridShape') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InsertHybridShape(HybridShape iHybridShape)
                | 
                |     Inserts a hybrid shape to the ordered geometrical set.
                | 
                |     Parameters:
                | 
                |         iHybridShape
                |             The hybrid shape to insert. 
                | 
                |     Example:
                |         This example inserts the hybrid shape HybridShape1 to the ordered
                |         geometrical set OrderedGeometricalSet1:
                | 
                |          OrderedGeometricalSet1.InsertHybridShape
                |          (HybridShape1)

        :param HybridShape i_hybrid_shape:
        :rtype: None
        """
        return self.ordered_geometrical_set.InsertHybridShape(i_hybrid_shape.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'insert_hybrid_shape'
        # # vba_code = """
        # # Public Function insert_hybrid_shape(ordered_geometrical_set)
        # #     Dim iHybridShape (2)
        # #     ordered_geometrical_set.InsertHybridShape iHybridShape
        # #     insert_hybrid_shape = iHybridShape
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'OrderedGeometricalSet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.system_interfaces.any_object import AnyObject


class EkpServices(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     EKPServices
                | 
                | Interface to assign and remove Engineering Requirements to and from an
                | activity.
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.ekp_services = com_object

    def assign_er(self, i_geometric_feature: AnyObject, i_fta: AnyObject, i_operation: Activity, i_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AssignER(CATBaseDispatch iGeometricFeature,
                | CATBaseDispatch iFTA,
                | Activity iOperation,
                | ItemAssignmentType iType)
                | 
                |     Assigns the passed geometric feature to the operation.
                | 
                |     Parameters:
                | 
                |         iGeometricFeature
                |             [in] Geometric Element user wants to assign User has a handle to
                |             this object 
                |         iFTA
                |             [in] Underlying FTA object associated with the geometric feature
                |             Can be obtained using CAA C++ API exposed by CATIA FTA Modeler and passed to
                |             this API 
                |         iOperation
                |             [in] The Operation to which assignment needs to be done User has a
                |             handle to this object 
                |         iType
                |             [in] Type of assignment whether ‘Partial’ or ‘Complete’ User needs
                |             to know what type of assignment he/she wants to
                |             make

        :param AnyObject i_geometric_feature:
        :param AnyObject i_fta:
        :param Activity i_operation:
        :param int i_type: enum item_assignment_type
        :rtype: None
        """
        return self.ekp_services.AssignER(
            i_geometric_feature.com_object,
            i_fta.com_object,
            i_operation.com_object,
            i_type
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'assign_er'
        # # vba_code = """
        # # Public Function assign_er(ekp_services)
        # #     Dim iGeometricFeature (2)
        # #     ekp_services.AssignER iGeometricFeature
        # #     assign_er = iGeometricFeature
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def assign_er_with_fta(self, i_fta: AnyObject, i_operation: Activity, i_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AssignERWithFTA(CATBaseDispatch iFTA,
                | Activity iOperation,
                | ItemAssignmentType iType)
                | 
                |     Assigns the passed FTA to the Operation .
                | 
                |     Parameters:
                | 
                |         iFTA
                |             [in] FTA to be passed 
                |         iOperation
                |             [in] The Operation to which assignment needs to be done
                |             
                |         iType
                |             [in] type of assignment - partial or complete

        :param AnyObject i_fta:
        :param Activity i_operation:
        :param int i_type: enum item_assignment_type
        :rtype: None
        """
        return self.ekp_services.AssignERWithFTA(i_fta.com_object, i_operation.com_object, i_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'assign_er_with_fta'
        # # vba_code = """
        # # Public Function assign_er_with_fta(ekp_services)
        # #     Dim iFTA (2)
        # #     ekp_services.AssignERWithFTA iFTA
        # #     assign_er_with_fta = iFTA
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_assigned_er(self, i_operation: Activity, i_type: int, o_item_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAssignedER(Activity iOperation,
                | ItemAssignmentType iType,
                | CATSafeArrayVariant oItemList)
                | 
                |     Given a type of assignment, this method returns all the ER assigned to the
                |     Operation.
                | 
                |     Parameters:
                | 
                |         iOperation
                |             [in] The Operation to which assignment needs to be done
                |             
                |         iType
                |             [in] the type of assignment, it could be partial or complete
                |             
                |         oItemList
                |             [out] List of assigned ERs to the operation or
                |             activity

        :param Activity i_operation:
        :param int i_type: enum item_assignment_type
        :param tuple o_item_list:
        :rtype: None
        """
        return self.ekp_services.GetAssignedER(i_operation.com_object, i_type, o_item_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_assigned_er'
        # # vba_code = """
        # # Public Function get_assigned_er(ekp_services)
        # #     Dim iOperation (2)
        # #     ekp_services.GetAssignedER iOperation
        # #     get_assigned_er = iOperation
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_er_assignment(
            self,
            i_geometric_feature: AnyObject,
            i_fta: AnyObject,
            i_operation: Activity,
            i_type: int
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveERAssignment(CATBaseDispatch iGeometricFeature,
                | CATBaseDispatch iFTA,
                | Activity iOperation,
                | ItemAssignmentType iType)
                | 
                |     Removes the ER assignment for the passed Geometric
                |     Feature.
                | 
                |     Parameters:
                | 
                |         iGeometricFeature
                |             [in] The Geometric feature which will be unassigned
                |             
                |         iFTA
                |             [in] FTA to be passed 
                |         iOperation
                |             [in] The Operation to which assignment needs to be done
                |             
                |         iType
                |             [in] the type of assignment, it could be partial or
                |             complete

        :param AnyObject i_geometric_feature:
        :param AnyObject i_fta:
        :param Activity i_operation:
        :param int i_type: enum item_assignment_type
        :rtype: None
        """
        return self.ekp_services.RemoveERAssignment(
            i_geometric_feature.com_object,
            i_fta.com_object,
            i_operation.com_object,
            i_type
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_er_assignment'
        # # vba_code = """
        # # Public Function remove_er_assignment(ekp_services)
        # #     Dim iGeometricFeature (2)
        # #     ekp_services.RemoveERAssignment iGeometricFeature
        # #     remove_er_assignment = iGeometricFeature
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_er_with_fta(self, i_fta: AnyObject, i_operation: Activity, i_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveERWithFTA(CATBaseDispatch iFTA,
                | Activity iOperation,
                | ItemAssignmentType iType)
                | 
                |     Removes the ER assignment for the passed FTA.
                | 
                |     Parameters:
                | 
                |         iFTA
                |             [in] the FTA to be passed to the operation 
                |         iOperation
                |             [in] The Operation to which assignment needs to be done
                |             
                |         iType
                |             [in] the type of assignment - partial or complete

        :param AnyObject i_fta:
        :param Activity i_operation:
        :param int i_type: enum item_assignment_type
        :rtype: None
        """
        return self.ekp_services.RemoveERWithFTA(i_fta.com_object, i_operation.com_object, i_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_er_with_fta'
        # # vba_code = """
        # # Public Function remove_er_with_fta(ekp_services)
        # #     Dim iFTA (2)
        # #     ekp_services.RemoveERWithFTA iFTA
        # #     remove_er_with_fta = iFTA
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'EkpServices(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arrangement_contour import ArrangementContour
from pycatia.arrangement_interfaces.arrangement_rectangle import ArrangementRectangle
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ArrangementContours(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ArrangementContours
                | 
                | A collection object for ArrangementContours of an Area.
                | Role: Use this to manage (create, retrieve and remove) ArrangementContours of
                | an ArrangementArea.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ArrangementContour)
        self.arrangement_contours = com_object

    def add_rectangular_contour(self, i_rectangle: ArrangementRectangle) -> ArrangementContour:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddRectangularContour(ArrangementRectangle iRectangle) As
                | ArrangementContour
                | 
                |     Creates a Rectangular Contour by adding a ArrangementRectangle to the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iRectangle
                |             ArrangementRectangle to create the contour from. 
                | 
                |     Returns:
                |         Returns the newly created ArrangementContour object and adds it to the
                |         collection.

        :param ArrangementRectangle i_rectangle:
        :rtype: ArrangementContour
        """
        return ArrangementContour(self.arrangement_contours.AddRectangularContour(i_rectangle.com_object))

    def item(self, i_index: cat_variant) -> ArrangementContour:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ArrangementContour
                | 
                |     Returns the specified ArrangementContour item of the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ArrangementContour to retrieve from
                |             this collection.
                | 
                |             To retrieve a specific object by number, use the rank of the
                |             ArrangementContour in that collection.
                |                 Note that the index of the first element in the collection is
                |                 1, and the index of the last element is Count. To retrieve a specific
                |                 ArrangementContour by name, use name that you assigned using the
                |                 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved ArrangementContour object.

        :param cat_variant i_index:
        :rtype: ArrangementContour
        """
        return ArrangementContour(self.arrangement_contours.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes the specified ArrangementContour object from the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ArrangementContour to remove from this
                |             collection.
                | 
                |             To remove a specific object by number, use the rank of the
                |             ArrangementContour in that collection.
                |                 Note that the index of the first element in the collection is
                |                 1, and the index of the last element is Count. To remove a specific
                |                 ArrangementContour by name, use name that you assigned using the
                |                 
                | 
                |         AnyObject.Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.arrangement_contours.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(arrangement_contours)
        # #     Dim iIndex (2)
        # #     arrangement_contours.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ArrangementContours(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.navigator_interfaces.group import Group
from pycatia.system_interfaces.collection import Collection


class Merges(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Merges
                | 
                | Interface to compute CATIAMerges
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.merges = com_object

    def clean_up(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CleanUp()
                | 
                |     Performs some clean-up.

        :rtype: None
        """
        return self.merges.CleanUp()

    def compute_merge(
            self,
            group_of_selected_products: Group,
            i_accuracy_for_simplification: float,
            i_keep_edges: int,
            i_decoration: int
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeMerge(Group GroupOfSelectedProducts,
                | double iAccuracyForSimplification,
                | long iKeepEdges,
                | long iDecoration) As Document
                | 
                |     Computes the merge on the selected products.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform the 3D cut.
                |             
                |         iAccuracyForSimplification
                |             Set this to a non null value to have the simplification activated.
                |             
                |         iKeepEdges
                |             Do you want edges in the result? 
                |         iDecoration
                |             Do you want decorations in the result? 
                | 
                |     Returns:
                |         MergeDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param float i_accuracy_for_simplification:
        :param int i_keep_edges:
        :param int i_decoration:
        :rtype: Document
        """
        return Document(
            self.merges.ComputeMerge(
                group_of_selected_products.com_object,
                i_accuracy_for_simplification,
                i_keep_edges,
                i_decoration
            )
        )

    def merge_shape_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func MergeShapeName() As CATBSTR
                | 
                |     Returns the name of the associated shape.

        :rtype: str
        """
        return self.merges.MergeShapeName()

    def __repr__(self):
        return f'Merges(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connector import SchAppConnector
from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchAppConnection(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppConnection
                | 
                | Manage a schematic connection.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_connection = com_object

    def app_add_connector(self, i_cntr_to_add: SchAppConnector) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppAddConnector(SchAppConnector iCntrToAdd)
                | 
                |     Add a connector.
                | 
                |     Parameters:
                | 
                |         iCntrToAdd
                |             The Application Connector to be added to the connection
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnection
                |          Dim objArg1 As SchAppConnector
                |           ...
                |          objThisIntf.AppAddConnectorobjArg1

        :param SchAppConnector i_cntr_to_add:
        :rtype: None
        """
        return self.sch_app_connection.AppAddConnector(i_cntr_to_add.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_add_connector'
        # # vba_code = """
        # # Public Function app_add_connector(sch_app_connection)
        # #     Dim iCntrToAdd (2)
        # #     sch_app_connection.AppAddConnector iCntrToAdd
        # #     app_add_connector = iCntrToAdd
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_list_connectables(
            self,
            i_l_cntble_class_filter: SchListOfBSTRs,
            o_l_cntbles: SchListOfObjects,
            o_l_cntrs: SchListOfObjects
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppListConnectables(SchListOfBSTRs
                | iLCntbleClassFilter,
                | SchListOfObjects oLCntbles,
                | SchListOfObjects oLCntrs)
                | 
                |     Find all the application object connected to this connection through their
                |     connectors.
                | 
                |     Parameters:
                | 
                |         oLCntrClassFilter
                |             A list of all the class types for filtering the output application
                |             objects list. 
                |         oLCntbles
                |             A list of application objects connected to this connection.
                |             (members are CATISchAppConnectable interface pointers).
                |             
                |         oLCntrs
                |             A list of connectors through which this connection is made.
                |             (members are CATISchAppConnector interface pointers).
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnection
                |          Dim objArg1 As SchListOfBSTRs
                |          Dim objArg2 As SchListOfObjects
                |          Dim objArg3 As SchListOfObjects
                |           ...
                |         
                |         objThisIntf.AppListConnectablesobjArg1,objArg2,objArg3

        :param SchListOfBSTRs i_l_cntble_class_filter:
        :param SchListOfObjects o_l_cntbles:
        :param SchListOfObjects o_l_cntrs:
        :rtype: None
        """
        return self.sch_app_connection.AppListConnectables(
            i_l_cntble_class_filter.com_object,
            o_l_cntbles.com_object,
            o_l_cntrs.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_list_connectables'
        # # vba_code = """
        # # Public Function app_list_connectables(sch_app_connection)
        # #     Dim iLCntbleClassFilter (2)
        # #     sch_app_connection.AppListConnectables iLCntbleClassFilter
        # #     app_list_connectables = iLCntbleClassFilter
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_list_connectors(self, i_l_cntr_class_filter: SchListOfBSTRs) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppListConnectors(SchListOfBSTRs iLCntrClassFilter) As
                | SchListOfObjects
                | 
                |     Find all the connectors included in this connection.
                | 
                |     Parameters:
                | 
                |         oLCntrClassFilter
                |             A list of all the class types for filtering the output connector
                |             list. 
                |         oLCntrs
                |             A list of connectors included in this connection. (members are
                |             CATISchAppConnector interface pointers). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnection
                |          Dim objArg1 As SchListOfBSTRs
                |          Dim objArg2 As SchListOfObjects
                |           ...
                |          Set objArg2 = objThisIntf.AppListConnectors(objArg1)

        :param SchListOfBSTRs i_l_cntr_class_filter:
        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_app_connection.AppListConnectors(i_l_cntr_class_filter.com_object))

    def app_remove_connector(self, i_cntr_to_remove: SchAppConnector) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppRemoveConnector(SchAppConnector iCntrToRemove)
                | 
                |     Remove a connector.
                | 
                |     Parameters:
                | 
                |         iCntrToRemove
                |             The Application Connector to be removed 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppConnection
                |          Dim objArg1 As SchAppConnector
                |           ...
                |          objThisIntf.AppRemoveConnectorobjArg1

        :param SchAppConnector i_cntr_to_remove:
        :rtype: None
        """
        return self.sch_app_connection.AppRemoveConnector(i_cntr_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_remove_connector'
        # # vba_code = """
        # # Public Function app_remove_connector(sch_app_connection)
        # #     Dim iCntrToRemove (2)
        # #     sch_app_connection.AppRemoveConnector iCntrToRemove
        # #     app_remove_connector = iCntrToRemove
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppConnection(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.kinematics_interfaces.mechanism import Mechanism
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Mechanisms(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Mechanisms
                | 
                | A collection of all Mechanism entities currently managed by the
                | application.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Mechanism)
        self.mechanisms = com_object

    def add(self) -> Mechanism:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As Mechanism
                | 
                |     Creates a new Mechanism and adds it to the Mechanisms
                |     collection.
                | 
                |     Returns:
                |         The created Mechanism 
                |     Example:
                |         This example creates a new Mechanism in the TheMechanisms
                |         collection.
                | 
                |             Dim NewMechanism As Mechanism
                |             Set NewMechanism = TheMechanisms.Add()

        :rtype: Mechanism
        """
        return Mechanism(self.mechanisms.Add())

    def item(self, i_index: cat_variant) -> Mechanism:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Mechanism
                | 
                |     Returns a Mechanism using its index or its name from the Mechanisms
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Mechanism to retrieve from the
                |             collection of Mechanisms. As a numerics, this index is the rank of the
                |             Mechanism in the collection. The index of the first Mechanism in the collection
                |             is 1, and the index of the last Mechanism is Count. As a string, it is the name
                |             you assigned to the Mechanism using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved Mechanism 
                |     Example:
                |         This example returns in ThisMechanism the third Mechanism in the
                |         collection, and in ThatMechanism the Mechanism named
                |         MyMechanism.
                | 
                |          Dim ThisMechanism As Mechanism
                |          Set ThisMechanism = TheMechanisms.Item(3)
                |          Dim ThatMechanism As Mechanism
                |          Set ThatMechanism = CATIA.Mechanisms.Item("MyMechanism")

        :param cat_variant i_index:
        :rtype: Mechanism
        """
        return Mechanism(self.mechanisms.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a Mechanism from the Mechanisms collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Mechanism to retrieve from the
                |             collection of mechanisms. As a numerics, this index is the rank of the
                |             Mechanism in the collection. The index of the first Mechanism in the collection
                |             is 1, and the index of the last Mechanism is Count. As a string, it is the name
                |             you assigned to the Mechanism. 
                | 
                |     Returns:
                |         Nothing 
                |     Example:
                |         The following example removes the tenth Mechanism and the Mechanism
                |         named MechanismTwo from the TheMechanisms collection.
                | 
                |             TheMechanisms.Remove(10)
                |             TheMechanisms.Remove("MechanismTwo")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.mechanisms.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(mechanisms)
        # #     Dim iIndex (2)
        # #     mechanisms.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Mechanisms(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class BasicDevice(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     BasicDevice
                | 
                | Interface representing a Basic Device.
                | 
                | Role: This interface is used to interact with devices that are available in the
                | Device Building workbench. This includes devices created in both V5 and
                | D5.
                | The following code snippet can be used to obtain a device in a CATProduct
                | document.
                | 
                |    Dim objDevice As BasicDevice
                |    set objDevice = CATIA.ActiveDocument.Product.GetTechnologicalObject("BasicDevice")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.basic_device = com_object

    def get_dof_values(self, o_values: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDOFValues(CATSafeArrayVariant oValues)
                | 
                |     Get the DOF values for the device.
                | 
                |     Parameters:
                | 
                |         oValues
                |             This contains a list of the current DOF values. Please note that
                |             distances are measured in meters and angles in radians.
                |
                |     Example:
                |
                |            Dim objDevice As BasicDevice
                |            set objDevice = CATIA.ActiveDocument.Product.GetTechnologicalObject("BasicDevice")
                |            Dim ListOfDOFValues () 
                |            objDevice.GetDOFValues ListOfDOFValues
                |            For i = 0 to ubound (ListOfDOFValues)
                |               ...
                |            Next

        :param tuple o_values:
        :rtype: None
        """
        return self.basic_device.GetDOFValues(o_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_dof_values'
        # # vba_code = """
        # # Public Function get_dof_values(basic_device)
        # #     Dim oValues (2)
        # #     basic_device.GetDOFValues oValues
        # #     get_dof_values = oValues
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_home_positions(self, o_home_pos_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetHomePositions(CATSafeArrayVariant oHomePosList)
                | 
                |     Get list of home positions of the device.
                | 
                |     Parameters:
                | 
                |         oHomePosList
                |             This outer parameter contains list of home position .
                |
                |     Returns:
                |         An HRESULT

        :param tuple o_home_pos_list:
        :rtype: None
        """
        return self.basic_device.GetHomePositions(o_home_pos_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_home_positions'
        # # vba_code = """
        # # Public Function get_home_positions(basic_device)
        # #     Dim oHomePosList (2)
        # #     basic_device.GetHomePositions oHomePosList
        # #     get_home_positions = oHomePosList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_home_position(self, i_name: str, idb_trans: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetHomePosition(CATBSTR iName,
                | CATSafeArrayVariant idbTrans)
                | 
                |     Set home position of the device.
                | 
                |     Parameters:
                | 
                |         iName
                |             This parameter contains name of home position . 
                |         idbTrans
                |             This parameter contains distance data in Meters or angular data in
                |             degree radian. 
                | 
                |     Returns:
                |         HRESULT indicate whether function succeed.

        :param str i_name:
        :param tuple idb_trans:
        :rtype: None
        """
        return self.basic_device.SetHomePosition(i_name, idb_trans)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_home_position'
        # # vba_code = """
        # # Public Function set_home_position(basic_device)
        # #     Dim iName (2)
        # #     basic_device.SetHomePosition iName
        # #     set_home_position = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'BasicDevice(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.fitting_interfaces.sampleds import Sampleds


class Tracks(Sampleds):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     FittingInterfaces.Sampleds
                |                         Tracks
                | 
                | A collection of all the track objects contained in the current
                | document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tracks = com_object

    def add_from_file(self, i_file_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddFromFile(CATBSTR iFileName)
                | 
                |     Creates a track in the collection, from information from an external
                |     file.
                | 
                |     Parameters:
                | 
                |         iFileName
                |             The path to a valid xml file. 
                |         Example:
                |             The following example reads a file called exmple.xml and creates a
                |             track in the tracks collection.
                | 
                |              myTracks.AddFromFile ("example.xml")

        :param str i_file_name:
        :rtype: None
        """
        return self.tracks.AddFromFile(i_file_name)

    def __repr__(self):
        return f'Tracks(name="{self.name}")'
